/*
 * Enhydra Java Application Server Project
 * 
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See 
 * the License for the specific terms governing rights and limitations
 * under the License.
 * 
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 * 
 * Contributor(s):
 * 
 * $Id: DiscDataStruct.java,v 1.1 2001/01/25 00:02:17 damon Exp $
 */
package org.enhydra.barracuda.discRack.data.disc;

import com.lutris.appserver.server.sql.*;
import java.sql.*;
import java.math.*;
import java.io.Serializable;

/**
 * Data structure for DO class.
 * A container for data members of a DO class.
 * A DO class contains a reference to a DataStruct class.  This reference
 * can be null (a DO whose data has not yet been retrieved from the database),
 * allowing a DO object to be a lightweight placeholder until its data is needed.
 *
 * @version $Revision: 1.1 $
 * @author  ChristianC
 * @since   discRack
 */
public class DiscDataStruct implements Cloneable, Serializable {

    /**
     * A DO refers to this DataStruct.
     * readOnly is set to true when the DO is stored in its class cache.
     */
    public boolean readOnly = false;

    private byte[] copyByteArray( byte[] source ) {
	byte[] dest = new byte[ source.length ];
	System.arraycopy( source, 0, dest, 0, source.length );
	return dest;
    }

/**
 * 
 */
   public String title = null;

/**
 * 
 */
   public String artist = null;

/**
 * 
 */
   public String genre = null;

/**
 *Attribute describing a link to the owner of this disc. 
 */
   public org.enhydra.barracuda.discRack.data.person.PersonDO owner = null;

/**
 * A flag indicating whether the user likes this disc
 */
   public boolean isLiked = false;
    /**
     * Create a copy of the guts of a DO.
     *
     * @exception DatabaseManagerException 
     *       if createExisting() fails for a contained DO
     * @exception ObjectIdException 
     *       if GenericDO has trouble obtaining a valid id.
     */
    public DiscDataStruct duplicate() 
    throws DatabaseManagerException, ObjectIdException {
        DiscDataStruct ret = new DiscDataStruct ();
 

		
	ret.title = title + "";
	
	
	ret.artist = artist + "";
	
	
	ret.genre = genre + "";
	
	
	ret.owner = org.enhydra.barracuda.discRack.data.person.PersonDO.createCopy( owner );
	
	
	ret.isLiked = isLiked;
	


	return ret;
    }
}
