/*
 * Enhydra Java Application Server Project
 * 
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See 
 * the License for the specific terms governing rights and limitations
 * under the License.
 * 
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 * 
 * Contributor(s):
 * 
 * $Id: PersonDOI.java,v 1.1 2001/01/25 00:02:17 damon Exp $
 */
package org.enhydra.barracuda.discRack.data.person;

import java.io.*;
import java.sql.*;
import java.math.*;
import com.lutris.appserver.server.*;
import com.lutris.appserver.server.sql.*;
import com.lutris.dods.builder.generator.query.*;


/**
 * Interface implemented by PersonDO.
 * Interface could also be implemented by a (hand-written) Business Layer class
 * which uses PersonDO.
 *
 * @version $Revision: 1.1 $
 * @author  ChristianC
 * @since   discRack
 */
public interface PersonDOI {


////////////////////////// data member Login


   /**
    * Get login of the person
    *
    * @return login of the person
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public String getLogin () 
   throws DataObjectException;

   
   /**
    * Set login of the person
    *
    * @param login of the person
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public void setLogin ( String login )
   throws DataObjectException;
   


////////////////////////// data member Password


   /**
    * Get password of the person
    *
    * @return password of the person
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public String getPassword () 
   throws DataObjectException;

   
   /**
    * Set password of the person
    *
    * @param password of the person
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public void setPassword ( String password )
   throws DataObjectException;
   


////////////////////////// data member Firstname


   /**
    * Get firstname of the person
    *
    * @return firstname of the person
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public String getFirstname () 
   throws DataObjectException;

   
   /**
    * Set firstname of the person
    *
    * @param firstname of the person
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public void setFirstname ( String firstname )
   throws DataObjectException;
   


////////////////////////// data member Lastname


   /**
    * Get lastname of the person
    *
    * @return lastname of the person
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public String getLastname () 
   throws DataObjectException;

   
   /**
    * Set lastname of the person
    *
    * @param lastname of the person
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public void setLastname ( String lastname )
   throws DataObjectException;
   


  /**
   * Inserts/Updates the DO into its table.
   *
   * @exception com.lutris.appserver.server.sql.DatabaseManagerException if a Transaction can not be created.
   * @exception RefAssertionException thrown by okTo method.
   * @exception java.sql.SQLException if any SQL errors occur.
   */
  public void save() 
  throws SQLException, DatabaseManagerException, DataObjectException, RefAssertionException, DBRowUpdateException, QueryException;

  /**
   * Inserts/Updates the DO into its table.
   * The transaction is likely provided by the save() method of another DO
   * which references this DO.
   * 
   * @param dbt The transaction object to use for this operation.
   * @exception com.lutris.appserver.server.sql.DatabaseManagerException if a Transaction can not be created.
   * @exception com.lutris.appserver.server.sql.DBRowUpdateException if a version error occurs.
   * @exception RefAssertionException thrown by okTo method.
   * @exception java.sql.SQLException if any SQL errors occur.
   */
  public void save(DBTransaction dbt)
  throws SQLException, DatabaseManagerException, DataObjectException, RefAssertionException, DBRowUpdateException, QueryException;

  /**
   * Inserts/Updates the DO into its table.
   *
   * @exception com.lutris.appserver.server.sql.DatabaseManagerException if a Transaction can not be created.
   * @exception RefAssertionException thrown by okTo method.
   * @exception java.sql.SQLException if any SQL errors occur.
   * @deprecated Use save() instead.
   */
  public void commit() 
  throws SQLException, DatabaseManagerException, DataObjectException, RefAssertionException, DBRowUpdateException, QueryException;

  /**
   * Inserts/Updates the DO into its table.
   * The transaction is likely provided by the commit() method of another DO
   * which references this DO.
   * 
   * @param dbt The transaction object to use for this operation.
   * @exception com.lutris.appserver.server.sql.DatabaseManagerException if a Transaction can not be created.
   * @exception com.lutris.appserver.server.sql.DBRowUpdateException if a version error occurs.
   * @exception RefAssertionException thrown by okTo method.
   * @exception java.sql.SQLException if any SQL errors occur.
   * @deprecated Use save() instead.
   */
  public void commit(DBTransaction dbt)
  throws SQLException, DatabaseManagerException, DataObjectException, RefAssertionException, DBRowUpdateException, QueryException;

  /**
   * Deletes the DO from its table.
   *
   * @exception com.lutris.appserver.server.sql.DatabaseManagerException if a Transaction can not be created.
   * @exception RefAssertionException thrown by okTo method.
   * @exception java.sql.SQLException if any SQL errors occur.
   */
  public void delete() 
  throws SQLException, DatabaseManagerException, DataObjectException, RefAssertionException, DBRowUpdateException, QueryException;

  /**
   * Deletes the DO from its table.
   * The transaction is likely provided by the delete() method of another DO
   * which references this DO.
   *
   * @param dbt The transaction object to use for this operation.
   * @exception com.lutris.appserver.server.sql.DatabaseManagerException if a Transaction can not be created.
   * @exception com.lutris.appserver.server.sql.DBRowUpdateException if a version error occurs.
   * @exception RefAssertionException thrown by okTo method.
   * @exception java.sql.SQLException if any SQL errors occur.
   */
  public void delete(DBTransaction dbt)
  throws SQLException, DatabaseManagerException, DataObjectException, RefAssertionException, DBRowUpdateException, QueryException;

}
