/**
 * jsrsClientServerHTTPLib.js - javascript library to make make asynchronous
 * remote calls to server without client page refresh (based off Brent
 * Ashley's [jsrs@megahuge.com] jsrsClient.js). See http://www.ashleyit.com/rs/jsrs/
 * for details.
 *
 * see jsrsLicense.txt for copyright and license information
 *
 * changes:
 * 08/20/2001 - revamped to interact with the Barracuda ParamGateway servlet; the
 *		script submits a form to the servlet, which saves all the form values in
 * 		session state, and then returns a url to the client (which can then do
 *		a location.replace on that url).
 */
// callback pool needs global scope
var jsrsContextPoolSize = 0;
var jsrsContextMaxPool = 10;
var jsrsContextPool = new Array();
var jsrsBrowser = jsrsBrowserSniff();
var jsrsPOST = true;

//--------------------- Public functions ----------------------------
/**
 * Used to submit a form without causing a screen refresh
 */
function submitAndReplace(targetForm) {
	jsrsSubmit(targetForm, myCallback, false);
}
function submitAndReplace(targetForm, debug) {
	jsrsSubmit(targetForm, myCallback, debug);
}

//--------------------- Utility functions ---------------------------
/**
 * callback function that receives the resulting redirect URL and replaces the
 * URL accordingly
 */
function myCallback(result) {
	location.replace(result);
}

/**
 * constructor for context object
 */
function jsrsContextObj(contextID) {
    // properties
    this.id = contextID;
    this.busy = true;
    this.callback = null;
    this.container = contextCreateContainer(contextID);

    // methods
    this.GET = contextGET;
    this.POST = contextPOST;
    this.getPayload = contextGetPayload;
    this.setVisibility = contextSetVisibility;
}

/**
 *  method functions are not privately scoped
 *  because Netscape's debugger chokes on private functions
 */
function contextCreateContainer(containerName){
    // creates hidden container to receive server data
    var container;
    switch(jsrsBrowser) {
    case 'NS':
        container = new Layer(100);
        container.name = containerName;
        container.visibility = 'hidden';
        container.clip.width = 100;
        container.clip.height = 100;
        break;

    case 'IE':
        document.body.insertAdjacentHTML("afterBegin", '<span id="SPAN' + containerName + '"></span>');
        var span = document.all("SPAN" + containerName);
        var html = '<iframe name="' + containerName + '" src=""></iframe>';
        span.innerHTML = html;
        span.style.display = 'none';
        container = window.frames[ containerName ];
        break;

    case 'MOZ':
        var span = document.createElement('SPAN');
        span.id = "SPAN" + containerName;
        document.body.appendChild(span);
        var iframe = document.createElement('IFRAME');
        iframe.name = containerName;
        span.appendChild(iframe);
        container = iframe;
        break;
    }
    return container;
}

/**
 *
 */
function contextPOST(sourceForm, vis) {
	//preliminary stuff
	var d = new Date();
	var unique = d.getTime() + '' + Math.floor(1000 * Math.random());
	var doc = this.container.document;
    var sep = "?";
    if (sourceForm.action.indexOf(sep)>-1) sep = "&";

	//start building the form
	doc.open();
	doc.writeln('<html><body>');
	doc.writeln('  <form name="jsrsForm" method="'+sourceForm.method+'" target="" action="'+sourceForm.action+sep+'U='+unique+'">');
    doc.writeln('    <input type="hidden" name="pm_cid" value="' + this.id + '">');

	// add in form's input elements
	for (var i=0; i<sourceForm.elements.length; i++) {
	    var element = sourceForm.elements[i];

        //note that we skip buttons...this is because these are not really 
        //needed for the post information
        if ((element.type=="submit") || 
            (element.type=="reset") ||
            (element.type=="button")) continue;

        //select controls            
		if ((element.type=="select-one") || (element.type=="select-multiple")) {
    		if (element.type=="select-one") doc.write('    <select ');
			else doc.write('    <select multiple ');
			doc.write('name="'+element.name+'"');
			doc.writeln('>');
			var options = element.options;
			for (var j=0; j<options.length; j++) {
				var opt = options[j];
				doc.write('      <option ');
				doc.write('value="'+opt.value+'" ');
				if (opt.selected) doc.write('selected ');
				doc.writeln('>'+opt.text+'</option>');
			}
			doc.writeln('    </select>');

        //everything else
		} else {
			doc.write('    <input ');
			doc.write('type="'+element.type+'" ');
			doc.write('name="'+element.name+'" ');
			doc.write('value="'+element.value+'" ');
			if ((element.type=="checkbox") || (element.type=="radio")) {
                if (element.checked) doc.write('checked ');
			}
			doc.writeln('>');
		}
	}

	//finish up
	doc.writeln('    <input type="submit" value="Finish Submit!" name="jsrsSubmit">');
	doc.writeln('  </form>');
	doc.writeln('</body></html>');
	doc.close();
	if (!vis) doc.forms['jsrsForm'].submit();
}

/**
 *
 */
function contextGET(sourceForm) {
	//preliminary stuff
	var d = new Date();
	var unique = d.getTime() + '' + Math.floor(1000 * Math.random());
    var sep = "?";
    if (sourceForm.action.indexOf(sep)>-1) sep = "&";
	var url = sourceForm.action+sep+'U='+unique

	//add in the context id
	url += '&pm_cid='+this.id;

	// add in form's input elements
	for (var i=0; i<sourceForm.elements.length; i++) {
	    var element = sourceForm.elements[i];

        //note that we skip buttons...this is because these are not really 
        //needed for the post information
        if ((element.type=="submit") || 
            (element.type=="reset") ||
            (element.type=="button")) continue;

        //select controls
		if ((element.type=="select-one") || (element.type=="select-multiple")) {
			if (element.selectedIndex==-1) continue;
			var options = element.options;
			for (var j=0; j<options.length; j++) {
				var opt = options[j];
				if (opt.selected) url += '&'+element.name+'='+opt.value;
			}

        //everything else
		} else if ((element.type=="checkbox") || (element.type=="radio")) {
			if (element.checked) url += '&'+element.name+'='+element.value;

		} else {
			url += '&'+element.name+'='+element.value;
		}
	}

  // make the call
  switch(jsrsBrowser) {
    case 'NS':
      this.container.src = url;
      break;
    case 'IE':
      this.container.document.location.replace(url);
      break;
    case 'MOZ':
      this.container.src = '';
      this.container.src = url;
      break;
  }
}

/**
 * submit a form to the server from client code without causing a new page
 * to be loaded
 *
 * sourceForm  - the sourceForm
 * callback    - function to call on return
 *               or null if no return needed
 *               (passes returned string to callback)
 * visibility  - optional boolean to make container visible for debugging
 */
function jsrsSubmit(sourceForm, callback, visibility) {

	// get context
	var contextObj = jsrsContextPool[ jsrsGetContextID() ];
	contextObj.callback = callback;

	var vis = (visibility==null) ? false : visibility;
	contextObj.setVisibility(vis);

	if (sourceForm.method=='post' && ((jsrsBrowser=='IE') || (jsrsBrowser=='MOZ'))) {
		contextObj.POST(sourceForm, vis);
	} else {
		contextObj.GET(sourceForm);
	}

	return contextObj.id;
}

/**
 *
 */
function contextGetPayload(){
  switch(jsrsBrowser) {
    case 'NS':
      return this.container.document.forms['jsrs_Form'].elements['jsrs_Payload'].value;
    case 'IE':
      return this.container.document.forms['jsrs_Form']['jsrs_Payload'].value;
    case 'MOZ':
      return window.frames[this.container.name].document.forms['jsrs_Form']['jsrs_Payload'].value;
  }
}

/**
 *
 */
function contextSetVisibility(vis){
  switch(jsrsBrowser) {
    case 'NS':
      this.container.visibility = (vis)? 'show' : 'hidden';
      break;
    case 'IE':
      document.all("SPAN" + this.id).style.display = (vis)? '' : 'none';
      break;
    case 'MOZ':
      document.getElementById("SPAN" + this.id).style.visibility = (vis)? '' : 'hidden';
      this.container.width = (vis)? 250 : 0;
      this.container.height = (vis)? 100 : 0;
      break;
  }
}

// end of context constructor

/**
 *
 */
function jsrsGetContextID(){
  var contextObj;
  for (var i = 1; i <= jsrsContextPoolSize; i++){
    contextObj = jsrsContextPool[ 'jsrs' + i ];
    if (!contextObj.busy){
      contextObj.busy = true;
      return contextObj.id;
    }
  }
  // if we got here, there are no existing free contexts
  if (jsrsContextPoolSize <= jsrsContextMaxPool){
    // create new context
    var contextID = "jsrs" + (jsrsContextPoolSize + 1);
    jsrsContextPool[ contextID ] = new jsrsContextObj(contextID);
    jsrsContextPoolSize++;
    return contextID;
  } else {
    alert("jsrs Error:  context pool full");
    return null;
  }
}


/**
 *
 */
function jsrsLoaded(contextID){
  // get context object and invoke callback
  var contextObj = jsrsContextPool[ contextID ];
  if(contextObj.callback != null){
    contextObj.callback(jsrsUnescape(contextObj.getPayload()), contextID);
  }
  // clean up and return context to pool
  contextObj.callback = null;
  contextObj.busy = false;
}

/**
 *
 */
function jsrsError(contextID, str){
  alert(unescape(str));
  jsrsContextPool[ contextID ].busy = false
}

/**
 *
 */
function jsrsEscapeQQ(thing){
  return thing.replace(/'"'/g, '\\"');
}

/**
 *
 */
function jsrsUnescape(str){
  // payload has slashes escaped with whacks
  return str.replace(/\\\//g, "/");
}

/**
 *
 */
function jsrsBrowserSniff(){
  if (document.layers) return "NS";
  if (document.all) return "IE";
  if (document.getElementById) return "MOZ";
  return "OTHER";
}

/////////////////////////////////////////////////
//
// user functions

function jsrsArrayFromString(s, delim){
  // rebuild an array returned from server as string
  // optional delimiter defaults to ~
  var d = (delim == null)? '~' : delim;
  return s.split(d);
}

function jsrsDebugInfo(){
  // use for debugging by attaching to f1 (works with IE)
  // with onHelp = "return jsrsDebugInfo();" in the body tag
  var doc = window.open().document;
  doc.open;
  doc.write('Pool Size: ' + jsrsContextPoolSize + '<br><font face="arial" size="2"><b>');
  for(var i in jsrsContextPool){
    var contextObj = jsrsContextPool[i];
    doc.write('<hr>' + contextObj.id + ' : ' + (contextObj.busy ? 'busy' : 'available') + '<br>');
    doc.write(contextObj.container.document.location.pathname + '<br>');
    doc.write(contextObj.container.document.location.search + '<br>');
    doc.write('<table border="1"><tr><td>' + contextObj.container.document.body.innerHTML + '</td></tr></table>');
  }
  doc.write('</table>');
  doc.close();
  return false;
}